# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UserSshKeyArgs', 'UserSshKey']

@pulumi.input_type
class UserSshKeyArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[builtins.str],
                 title: pulumi.Input[builtins.str],
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a UserSshKey resource.
        :param pulumi.Input[builtins.str] key: The ssh key. The SSH key `comment` (trailing part) is optional and ignored for diffing, because GitLab overrides it with the username and GitLab hostname.
        :param pulumi.Input[builtins.str] title: The title of the ssh key.
        :param pulumi.Input[builtins.str] expires_at: The expiration date of the SSH key in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ)
        :param pulumi.Input[builtins.int] user_id: The ID or username of the user. If this field is omitted, this resource manages a SSH key for the current user. Otherwise, this resource manages a SSH key for the specified user, and an admin token is required.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "title", title)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[builtins.str]:
        """
        The ssh key. The SSH key `comment` (trailing part) is optional and ignored for diffing, because GitLab overrides it with the username and GitLab hostname.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def title(self) -> pulumi.Input[builtins.str]:
        """
        The title of the ssh key.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The expiration date of the SSH key in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ)
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID or username of the user. If this field is omitted, this resource manages a SSH key for the current user. Otherwise, this resource manages a SSH key for the specified user, and an admin token is required.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _UserSshKeyState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 key_id: Optional[pulumi.Input[builtins.int]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering UserSshKey resources.
        :param pulumi.Input[builtins.str] created_at: The time when this key was created in GitLab.
        :param pulumi.Input[builtins.str] expires_at: The expiration date of the SSH key in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ)
        :param pulumi.Input[builtins.str] key: The ssh key. The SSH key `comment` (trailing part) is optional and ignored for diffing, because GitLab overrides it with the username and GitLab hostname.
        :param pulumi.Input[builtins.int] key_id: The ID of the ssh key.
        :param pulumi.Input[builtins.str] title: The title of the ssh key.
        :param pulumi.Input[builtins.int] user_id: The ID or username of the user. If this field is omitted, this resource manages a SSH key for the current user. Otherwise, this resource manages a SSH key for the specified user, and an admin token is required.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if key_id is not None:
            pulumi.set(__self__, "key_id", key_id)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time when this key was created in GitLab.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The expiration date of the SSH key in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ)
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ssh key. The SSH key `comment` (trailing part) is optional and ignored for diffing, because GitLab overrides it with the username and GitLab hostname.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter(name="keyId")
    def key_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of the ssh key.
        """
        return pulumi.get(self, "key_id")

    @key_id.setter
    def key_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "key_id", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The title of the ssh key.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID or username of the user. If this field is omitted, this resource manages a SSH key for the current user. Otherwise, this resource manages a SSH key for the specified user, and an admin token is required.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "user_id", value)


class UserSshKey(pulumi.CustomResource):

    pulumi_type = "gitlab:index/userSshKey:UserSshKey"

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        The `UserSshKey` resource allows to manage the lifecycle of an SSH key assigned to a user.

        **Upstream API**: [GitLab API docs](https://docs.gitlab.com/api/users/#single-ssh-key)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.get_user(username="example-user")
        example_user_ssh_key = gitlab.UserSshKey("example",
            user_id=example.id,
            title="example-key",
            key="ssh-ed25519 AAAA...",
            expires_at="2016-01-21T00:00:00.000Z")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_user_sshkey`. For example:

        terraform

        import {

          to = gitlab_user_sshkey.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import a user ssh key using an id made up of `{user-id}:{key}`, e.g.

        ```sh
        $ pulumi import gitlab:index/userSshKey:UserSshKey example 42:1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] expires_at: The expiration date of the SSH key in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ)
        :param pulumi.Input[builtins.str] key: The ssh key. The SSH key `comment` (trailing part) is optional and ignored for diffing, because GitLab overrides it with the username and GitLab hostname.
        :param pulumi.Input[builtins.str] title: The title of the ssh key.
        :param pulumi.Input[builtins.int] user_id: The ID or username of the user. If this field is omitted, this resource manages a SSH key for the current user. Otherwise, this resource manages a SSH key for the specified user, and an admin token is required.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserSshKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `UserSshKey` resource allows to manage the lifecycle of an SSH key assigned to a user.

        **Upstream API**: [GitLab API docs](https://docs.gitlab.com/api/users/#single-ssh-key)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.get_user(username="example-user")
        example_user_ssh_key = gitlab.UserSshKey("example",
            user_id=example.id,
            title="example-key",
            key="ssh-ed25519 AAAA...",
            expires_at="2016-01-21T00:00:00.000Z")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_user_sshkey`. For example:

        terraform

        import {

          to = gitlab_user_sshkey.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import a user ssh key using an id made up of `{user-id}:{key}`, e.g.

        ```sh
        $ pulumi import gitlab:index/userSshKey:UserSshKey example 42:1
        ```

        :param str resource_name: The name of the resource.
        :param UserSshKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserSshKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserSshKeyArgs.__new__(UserSshKeyArgs)

            __props__.__dict__["expires_at"] = expires_at
            if key is None and not opts.urn:
                raise TypeError("Missing required property 'key'")
            __props__.__dict__["key"] = key
            if title is None and not opts.urn:
                raise TypeError("Missing required property 'title'")
            __props__.__dict__["title"] = title
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["key_id"] = None
        super(UserSshKey, __self__).__init__(
            'gitlab:index/userSshKey:UserSshKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            expires_at: Optional[pulumi.Input[builtins.str]] = None,
            key: Optional[pulumi.Input[builtins.str]] = None,
            key_id: Optional[pulumi.Input[builtins.int]] = None,
            title: Optional[pulumi.Input[builtins.str]] = None,
            user_id: Optional[pulumi.Input[builtins.int]] = None) -> 'UserSshKey':
        """
        Get an existing UserSshKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_at: The time when this key was created in GitLab.
        :param pulumi.Input[builtins.str] expires_at: The expiration date of the SSH key in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ)
        :param pulumi.Input[builtins.str] key: The ssh key. The SSH key `comment` (trailing part) is optional and ignored for diffing, because GitLab overrides it with the username and GitLab hostname.
        :param pulumi.Input[builtins.int] key_id: The ID of the ssh key.
        :param pulumi.Input[builtins.str] title: The title of the ssh key.
        :param pulumi.Input[builtins.int] user_id: The ID or username of the user. If this field is omitted, this resource manages a SSH key for the current user. Otherwise, this resource manages a SSH key for the specified user, and an admin token is required.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserSshKeyState.__new__(_UserSshKeyState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["key"] = key
        __props__.__dict__["key_id"] = key_id
        __props__.__dict__["title"] = title
        __props__.__dict__["user_id"] = user_id
        return UserSshKey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        The time when this key was created in GitLab.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The expiration date of the SSH key in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ)
        """
        return pulumi.get(self, "expires_at")

    @property
    @pulumi.getter
    def key(self) -> pulumi.Output[builtins.str]:
        """
        The ssh key. The SSH key `comment` (trailing part) is optional and ignored for diffing, because GitLab overrides it with the username and GitLab hostname.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter(name="keyId")
    def key_id(self) -> pulumi.Output[builtins.int]:
        """
        The ID of the ssh key.
        """
        return pulumi.get(self, "key_id")

    @property
    @pulumi.getter
    def title(self) -> pulumi.Output[builtins.str]:
        """
        The title of the ssh key.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[builtins.int]:
        """
        The ID or username of the user. If this field is omitted, this resource manages a SSH key for the current user. Otherwise, this resource manages a SSH key for the specified user, and an admin token is required.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['GroupProjectFileTemplateArgs', 'GroupProjectFileTemplate']

@pulumi.input_type
class GroupProjectFileTemplateArgs:
    def __init__(__self__, *,
                 file_template_project_id: pulumi.Input[builtins.int],
                 group_id: pulumi.Input[builtins.int]):
        """
        The set of arguments for constructing a GroupProjectFileTemplate resource.
        :param pulumi.Input[builtins.int] file_template_project_id: The ID of the project that will be used for file templates. This project must be the direct
               			child of the project defined by the group_id
        :param pulumi.Input[builtins.int] group_id: The ID of the group that will use the file template project. This group must be the direct
                           parent of the project defined by project_id
        """
        pulumi.set(__self__, "file_template_project_id", file_template_project_id)
        pulumi.set(__self__, "group_id", group_id)

    @property
    @pulumi.getter(name="fileTemplateProjectId")
    def file_template_project_id(self) -> pulumi.Input[builtins.int]:
        """
        The ID of the project that will be used for file templates. This project must be the direct
        			child of the project defined by the group_id
        """
        return pulumi.get(self, "file_template_project_id")

    @file_template_project_id.setter
    def file_template_project_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "file_template_project_id", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[builtins.int]:
        """
        The ID of the group that will use the file template project. This group must be the direct
                    parent of the project defined by project_id
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "group_id", value)


@pulumi.input_type
class _GroupProjectFileTemplateState:
    def __init__(__self__, *,
                 file_template_project_id: Optional[pulumi.Input[builtins.int]] = None,
                 group_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering GroupProjectFileTemplate resources.
        :param pulumi.Input[builtins.int] file_template_project_id: The ID of the project that will be used for file templates. This project must be the direct
               			child of the project defined by the group_id
        :param pulumi.Input[builtins.int] group_id: The ID of the group that will use the file template project. This group must be the direct
                           parent of the project defined by project_id
        """
        if file_template_project_id is not None:
            pulumi.set(__self__, "file_template_project_id", file_template_project_id)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)

    @property
    @pulumi.getter(name="fileTemplateProjectId")
    def file_template_project_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of the project that will be used for file templates. This project must be the direct
        			child of the project defined by the group_id
        """
        return pulumi.get(self, "file_template_project_id")

    @file_template_project_id.setter
    def file_template_project_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "file_template_project_id", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of the group that will use the file template project. This group must be the direct
                    parent of the project defined by project_id
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "group_id", value)


class GroupProjectFileTemplate(pulumi.CustomResource):

    pulumi_type = "gitlab:index/groupProjectFileTemplate:GroupProjectFileTemplate"

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 file_template_project_id: Optional[pulumi.Input[builtins.int]] = None,
                 group_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        The `GroupProjectFileTemplate` resource allows setting a project from which
        custom file templates will be loaded. In order to use this resource, the project selected must be a direct child of
        the group selected. After the resource has run, `gitlab_project_template.template_project_id` is available for use.
        For more information about which file types are available as templates, view
        [GitLab's documentation](https://docs.gitlab.com/user/group/custom_project_templates/)

        > This resource requires a GitLab Enterprise instance with a Premium license.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/groups/#update-group)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.Group("foo",
            name="group",
            path="group",
            description="An example group")
        bar = gitlab.Project("bar",
            name="template project",
            description="contains file templates",
            visibility_level="public",
            namespace_id=foo.id)
        template_link = gitlab.GroupProjectFileTemplate("template_link",
            group_id=foo.id,
            file_template_project_id=bar.id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] file_template_project_id: The ID of the project that will be used for file templates. This project must be the direct
               			child of the project defined by the group_id
        :param pulumi.Input[builtins.int] group_id: The ID of the group that will use the file template project. This group must be the direct
                           parent of the project defined by project_id
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupProjectFileTemplateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `GroupProjectFileTemplate` resource allows setting a project from which
        custom file templates will be loaded. In order to use this resource, the project selected must be a direct child of
        the group selected. After the resource has run, `gitlab_project_template.template_project_id` is available for use.
        For more information about which file types are available as templates, view
        [GitLab's documentation](https://docs.gitlab.com/user/group/custom_project_templates/)

        > This resource requires a GitLab Enterprise instance with a Premium license.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/groups/#update-group)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.Group("foo",
            name="group",
            path="group",
            description="An example group")
        bar = gitlab.Project("bar",
            name="template project",
            description="contains file templates",
            visibility_level="public",
            namespace_id=foo.id)
        template_link = gitlab.GroupProjectFileTemplate("template_link",
            group_id=foo.id,
            file_template_project_id=bar.id)
        ```

        :param str resource_name: The name of the resource.
        :param GroupProjectFileTemplateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupProjectFileTemplateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 file_template_project_id: Optional[pulumi.Input[builtins.int]] = None,
                 group_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupProjectFileTemplateArgs.__new__(GroupProjectFileTemplateArgs)

            if file_template_project_id is None and not opts.urn:
                raise TypeError("Missing required property 'file_template_project_id'")
            __props__.__dict__["file_template_project_id"] = file_template_project_id
            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
        super(GroupProjectFileTemplate, __self__).__init__(
            'gitlab:index/groupProjectFileTemplate:GroupProjectFileTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            file_template_project_id: Optional[pulumi.Input[builtins.int]] = None,
            group_id: Optional[pulumi.Input[builtins.int]] = None) -> 'GroupProjectFileTemplate':
        """
        Get an existing GroupProjectFileTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] file_template_project_id: The ID of the project that will be used for file templates. This project must be the direct
               			child of the project defined by the group_id
        :param pulumi.Input[builtins.int] group_id: The ID of the group that will use the file template project. This group must be the direct
                           parent of the project defined by project_id
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupProjectFileTemplateState.__new__(_GroupProjectFileTemplateState)

        __props__.__dict__["file_template_project_id"] = file_template_project_id
        __props__.__dict__["group_id"] = group_id
        return GroupProjectFileTemplate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="fileTemplateProjectId")
    def file_template_project_id(self) -> pulumi.Output[builtins.int]:
        """
        The ID of the project that will be used for file templates. This project must be the direct
        			child of the project defined by the group_id
        """
        return pulumi.get(self, "file_template_project_id")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[builtins.int]:
        """
        The ID of the group that will use the file template project. This group must be the direct
                    parent of the project defined by project_id
        """
        return pulumi.get(self, "group_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PersonalAccessTokenArgs', 'PersonalAccessToken']

@pulumi.input_type
class PersonalAccessTokenArgs:
    def __init__(__self__, *,
                 scopes: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 user_id: pulumi.Input[builtins.int],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 rotation_configuration: Optional[pulumi.Input['PersonalAccessTokenRotationConfigurationArgs']] = None):
        """
        The set of arguments for constructing a PersonalAccessToken resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] scopes: The scopes of the personal access token. valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `read_service_ping`
        :param pulumi.Input[builtins.int] user_id: The ID of the user.
        :param pulumi.Input[builtins.str] description: The description of the personal access token.
        :param pulumi.Input[builtins.str] expires_at: When the token will expire, YYYY-MM-DD format. Is automatically set when `rotation_configuration` is used.
        :param pulumi.Input[builtins.str] name: The name of the personal access token.
        :param pulumi.Input['PersonalAccessTokenRotationConfigurationArgs'] rotation_configuration: The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        """
        pulumi.set(__self__, "scopes", scopes)
        pulumi.set(__self__, "user_id", user_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rotation_configuration is not None:
            pulumi.set(__self__, "rotation_configuration", rotation_configuration)

    @property
    @pulumi.getter
    def scopes(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        The scopes of the personal access token. valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `read_service_ping`
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "scopes", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[builtins.int]:
        """
        The ID of the user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "user_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the personal access token.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When the token will expire, YYYY-MM-DD format. Is automatically set when `rotation_configuration` is used.
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the personal access token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="rotationConfiguration")
    def rotation_configuration(self) -> Optional[pulumi.Input['PersonalAccessTokenRotationConfigurationArgs']]:
        """
        The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        """
        return pulumi.get(self, "rotation_configuration")

    @rotation_configuration.setter
    def rotation_configuration(self, value: Optional[pulumi.Input['PersonalAccessTokenRotationConfigurationArgs']]):
        pulumi.set(self, "rotation_configuration", value)


@pulumi.input_type
class _PersonalAccessTokenState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[builtins.bool]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 revoked: Optional[pulumi.Input[builtins.bool]] = None,
                 rotation_configuration: Optional[pulumi.Input['PersonalAccessTokenRotationConfigurationArgs']] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 token: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering PersonalAccessToken resources.
        :param pulumi.Input[builtins.bool] active: True if the token is active.
        :param pulumi.Input[builtins.str] created_at: Time the token has been created, RFC3339 format.
        :param pulumi.Input[builtins.str] description: The description of the personal access token.
        :param pulumi.Input[builtins.str] expires_at: When the token will expire, YYYY-MM-DD format. Is automatically set when `rotation_configuration` is used.
        :param pulumi.Input[builtins.str] name: The name of the personal access token.
        :param pulumi.Input[builtins.bool] revoked: True if the token is revoked.
        :param pulumi.Input['PersonalAccessTokenRotationConfigurationArgs'] rotation_configuration: The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] scopes: The scopes of the personal access token. valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `read_service_ping`
        :param pulumi.Input[builtins.str] token: The token of the personal access token. **Note**: the token is not available for imported resources.
        :param pulumi.Input[builtins.int] user_id: The ID of the user.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if revoked is not None:
            pulumi.set(__self__, "revoked", revoked)
        if rotation_configuration is not None:
            pulumi.set(__self__, "rotation_configuration", rotation_configuration)
        if scopes is not None:
            pulumi.set(__self__, "scopes", scopes)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        True if the token is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Time the token has been created, RFC3339 format.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the personal access token.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When the token will expire, YYYY-MM-DD format. Is automatically set when `rotation_configuration` is used.
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the personal access token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def revoked(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        True if the token is revoked.
        """
        return pulumi.get(self, "revoked")

    @revoked.setter
    def revoked(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "revoked", value)

    @property
    @pulumi.getter(name="rotationConfiguration")
    def rotation_configuration(self) -> Optional[pulumi.Input['PersonalAccessTokenRotationConfigurationArgs']]:
        """
        The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        """
        return pulumi.get(self, "rotation_configuration")

    @rotation_configuration.setter
    def rotation_configuration(self, value: Optional[pulumi.Input['PersonalAccessTokenRotationConfigurationArgs']]):
        pulumi.set(self, "rotation_configuration", value)

    @property
    @pulumi.getter
    def scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The scopes of the personal access token. valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `read_service_ping`
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "scopes", value)

    @property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The token of the personal access token. **Note**: the token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "token", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of the user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "user_id", value)


class PersonalAccessToken(pulumi.CustomResource):

    pulumi_type = "gitlab:index/personalAccessToken:PersonalAccessToken"

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 rotation_configuration: Optional[pulumi.Input[Union['PersonalAccessTokenRotationConfigurationArgs', 'PersonalAccessTokenRotationConfigurationArgsDict']]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 user_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        The `PersonalAccessToken` resource allows to manage the lifecycle of a personal access token.

        > This resource requires administration privileges.

        > Use of the `timestamp()` function with expires_at will cause the resource to be re-created with every apply, it's recommended to use `plantimestamp()` or a static value instead.

        > Observability scopes are in beta and may not work on all instances. See more details in [the documentation](https://docs.gitlab.com/operations/tracing/)

        > Use `rotation_configuration` to automatically rotate tokens instead of using `timestamp()` as timestamp will cause changes with every plan. `pulumi up` must still be run to rotate the token.

        > Due to [Automatic reuse detection](https://docs.gitlab.com/api/personal_access_tokens/#automatic-reuse-detection) it's possible that a new Personal Access Token will immediately be revoked. Check if an old process using the old token is running if this happens.

        **Upstream API**: [GitLab API docs](https://docs.gitlab.com/api/personal_access_tokens/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.PersonalAccessToken("example",
            user_id=25,
            name="Example personal access token",
            expires_at="2020-03-14",
            scopes=["api"])
        example_project_variable = gitlab.ProjectVariable("example",
            project=example_gitlab_project["id"],
            key="pat",
            value=example.token)
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_personal_access_token`. For example:

        terraform

        import {

          to = gitlab_personal_access_token.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        A GitLab Personal Access Token can be imported using a key composed of `<user-id>:<token-id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/personalAccessToken:PersonalAccessToken example "12345:1"
        ```

        NOTE: the `token` resource attribute is not available for imported resources as this information cannot be read from the GitLab API.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: The description of the personal access token.
        :param pulumi.Input[builtins.str] expires_at: When the token will expire, YYYY-MM-DD format. Is automatically set when `rotation_configuration` is used.
        :param pulumi.Input[builtins.str] name: The name of the personal access token.
        :param pulumi.Input[Union['PersonalAccessTokenRotationConfigurationArgs', 'PersonalAccessTokenRotationConfigurationArgsDict']] rotation_configuration: The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] scopes: The scopes of the personal access token. valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `read_service_ping`
        :param pulumi.Input[builtins.int] user_id: The ID of the user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PersonalAccessTokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `PersonalAccessToken` resource allows to manage the lifecycle of a personal access token.

        > This resource requires administration privileges.

        > Use of the `timestamp()` function with expires_at will cause the resource to be re-created with every apply, it's recommended to use `plantimestamp()` or a static value instead.

        > Observability scopes are in beta and may not work on all instances. See more details in [the documentation](https://docs.gitlab.com/operations/tracing/)

        > Use `rotation_configuration` to automatically rotate tokens instead of using `timestamp()` as timestamp will cause changes with every plan. `pulumi up` must still be run to rotate the token.

        > Due to [Automatic reuse detection](https://docs.gitlab.com/api/personal_access_tokens/#automatic-reuse-detection) it's possible that a new Personal Access Token will immediately be revoked. Check if an old process using the old token is running if this happens.

        **Upstream API**: [GitLab API docs](https://docs.gitlab.com/api/personal_access_tokens/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.PersonalAccessToken("example",
            user_id=25,
            name="Example personal access token",
            expires_at="2020-03-14",
            scopes=["api"])
        example_project_variable = gitlab.ProjectVariable("example",
            project=example_gitlab_project["id"],
            key="pat",
            value=example.token)
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_personal_access_token`. For example:

        terraform

        import {

          to = gitlab_personal_access_token.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        A GitLab Personal Access Token can be imported using a key composed of `<user-id>:<token-id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/personalAccessToken:PersonalAccessToken example "12345:1"
        ```

        NOTE: the `token` resource attribute is not available for imported resources as this information cannot be read from the GitLab API.

        :param str resource_name: The name of the resource.
        :param PersonalAccessTokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PersonalAccessTokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 rotation_configuration: Optional[pulumi.Input[Union['PersonalAccessTokenRotationConfigurationArgs', 'PersonalAccessTokenRotationConfigurationArgsDict']]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 user_id: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PersonalAccessTokenArgs.__new__(PersonalAccessTokenArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["expires_at"] = expires_at
            __props__.__dict__["name"] = name
            __props__.__dict__["rotation_configuration"] = rotation_configuration
            if scopes is None and not opts.urn:
                raise TypeError("Missing required property 'scopes'")
            __props__.__dict__["scopes"] = scopes
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["active"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["revoked"] = None
            __props__.__dict__["token"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(PersonalAccessToken, __self__).__init__(
            'gitlab:index/personalAccessToken:PersonalAccessToken',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[builtins.bool]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            expires_at: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            revoked: Optional[pulumi.Input[builtins.bool]] = None,
            rotation_configuration: Optional[pulumi.Input[Union['PersonalAccessTokenRotationConfigurationArgs', 'PersonalAccessTokenRotationConfigurationArgsDict']]] = None,
            scopes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            token: Optional[pulumi.Input[builtins.str]] = None,
            user_id: Optional[pulumi.Input[builtins.int]] = None) -> 'PersonalAccessToken':
        """
        Get an existing PersonalAccessToken resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] active: True if the token is active.
        :param pulumi.Input[builtins.str] created_at: Time the token has been created, RFC3339 format.
        :param pulumi.Input[builtins.str] description: The description of the personal access token.
        :param pulumi.Input[builtins.str] expires_at: When the token will expire, YYYY-MM-DD format. Is automatically set when `rotation_configuration` is used.
        :param pulumi.Input[builtins.str] name: The name of the personal access token.
        :param pulumi.Input[builtins.bool] revoked: True if the token is revoked.
        :param pulumi.Input[Union['PersonalAccessTokenRotationConfigurationArgs', 'PersonalAccessTokenRotationConfigurationArgsDict']] rotation_configuration: The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] scopes: The scopes of the personal access token. valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `read_service_ping`
        :param pulumi.Input[builtins.str] token: The token of the personal access token. **Note**: the token is not available for imported resources.
        :param pulumi.Input[builtins.int] user_id: The ID of the user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PersonalAccessTokenState.__new__(_PersonalAccessTokenState)

        __props__.__dict__["active"] = active
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["name"] = name
        __props__.__dict__["revoked"] = revoked
        __props__.__dict__["rotation_configuration"] = rotation_configuration
        __props__.__dict__["scopes"] = scopes
        __props__.__dict__["token"] = token
        __props__.__dict__["user_id"] = user_id
        return PersonalAccessToken(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def active(self) -> pulumi.Output[builtins.bool]:
        """
        True if the token is active.
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Time the token has been created, RFC3339 format.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        The description of the personal access token.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[builtins.str]:
        """
        When the token will expire, YYYY-MM-DD format. Is automatically set when `rotation_configuration` is used.
        """
        return pulumi.get(self, "expires_at")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the personal access token.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def revoked(self) -> pulumi.Output[builtins.bool]:
        """
        True if the token is revoked.
        """
        return pulumi.get(self, "revoked")

    @property
    @pulumi.getter(name="rotationConfiguration")
    def rotation_configuration(self) -> pulumi.Output[Optional['outputs.PersonalAccessTokenRotationConfiguration']]:
        """
        The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        """
        return pulumi.get(self, "rotation_configuration")

    @property
    @pulumi.getter
    def scopes(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        The scopes of the personal access token. valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `read_service_ping`
        """
        return pulumi.get(self, "scopes")

    @property
    @pulumi.getter
    def token(self) -> pulumi.Output[builtins.str]:
        """
        The token of the personal access token. **Note**: the token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[builtins.int]:
        """
        The ID of the user.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetGroupAccessTokensResult',
    'AwaitableGetGroupAccessTokensResult',
    'get_group_access_tokens',
    'get_group_access_tokens_output',
]

@pulumi.output_type
class GetGroupAccessTokensResult:
    """
    A collection of values returned by getGroupAccessTokens.
    """
    def __init__(__self__, access_tokens=None, group=None, id=None):
        if access_tokens and not isinstance(access_tokens, list):
            raise TypeError("Expected argument 'access_tokens' to be a list")
        pulumi.set(__self__, "access_tokens", access_tokens)
        if group and not isinstance(group, str):
            raise TypeError("Expected argument 'group' to be a str")
        pulumi.set(__self__, "group", group)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="accessTokens")
    def access_tokens(self) -> Sequence['outputs.GetGroupAccessTokensAccessTokenResult']:
        """
        The list of access tokens returned by the search
        """
        return pulumi.get(self, "access_tokens")

    @property
    @pulumi.getter
    def group(self) -> builtins.str:
        """
        The name or id of the group.
        """
        return pulumi.get(self, "group")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")


class AwaitableGetGroupAccessTokensResult(GetGroupAccessTokensResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupAccessTokensResult(
            access_tokens=self.access_tokens,
            group=self.group,
            id=self.id)


def get_group_access_tokens(group: Optional[builtins.str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupAccessTokensResult:
    """
    The `gitlab_access_tokens` data source allows to retrieve all group-level access tokens.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/group_access_tokens/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    access_tokens = gitlab.get_group_access_tokens(group="my/example/group")
    ```


    :param builtins.str group: The name or id of the group.
    """
    __args__ = dict()
    __args__['group'] = group
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getGroupAccessTokens:getGroupAccessTokens', __args__, opts=opts, typ=GetGroupAccessTokensResult).value

    return AwaitableGetGroupAccessTokensResult(
        access_tokens=pulumi.get(__ret__, 'access_tokens'),
        group=pulumi.get(__ret__, 'group'),
        id=pulumi.get(__ret__, 'id'))
def get_group_access_tokens_output(group: Optional[pulumi.Input[builtins.str]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupAccessTokensResult]:
    """
    The `gitlab_access_tokens` data source allows to retrieve all group-level access tokens.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/group_access_tokens/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    access_tokens = gitlab.get_group_access_tokens(group="my/example/group")
    ```


    :param builtins.str group: The name or id of the group.
    """
    __args__ = dict()
    __args__['group'] = group
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getGroupAccessTokens:getGroupAccessTokens', __args__, opts=opts, typ=GetGroupAccessTokensResult)
    return __ret__.apply(lambda __response__: GetGroupAccessTokensResult(
        access_tokens=pulumi.get(__response__, 'access_tokens'),
        group=pulumi.get(__response__, 'group'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProjectHookArgs', 'ProjectHook']

@pulumi.input_type
class ProjectHookArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[builtins.str],
                 url: pulumi.Input[builtins.str],
                 confidential_issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 confidential_note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectHookCustomHeaderArgs']]]] = None,
                 custom_webhook_template: Optional[pulumi.Input[builtins.str]] = None,
                 deployment_events: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_ssl_verification: Optional[pulumi.Input[builtins.bool]] = None,
                 issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 job_events: Optional[pulumi.Input[builtins.bool]] = None,
                 merge_requests_events: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 pipeline_events: Optional[pulumi.Input[builtins.bool]] = None,
                 push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 push_events_branch_filter: Optional[pulumi.Input[builtins.str]] = None,
                 releases_events: Optional[pulumi.Input[builtins.bool]] = None,
                 resource_access_token_events: Optional[pulumi.Input[builtins.bool]] = None,
                 tag_push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 token: Optional[pulumi.Input[builtins.str]] = None,
                 wiki_page_events: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a ProjectHook resource.
        :param pulumi.Input[builtins.str] project: The name or id of the project to add the hook to.
        :param pulumi.Input[builtins.str] url: The url of the hook to invoke. Forces re-creation to preserve `token`.
        :param pulumi.Input[builtins.bool] confidential_issues_events: Invoke the hook for confidential issues events.
        :param pulumi.Input[builtins.bool] confidential_note_events: Invoke the hook for confidential note events.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectHookCustomHeaderArgs']]] custom_headers: Custom headers for the project webhook.
        :param pulumi.Input[builtins.str] custom_webhook_template: Custom webhook template.
        :param pulumi.Input[builtins.bool] deployment_events: Invoke the hook for deployment events.
        :param pulumi.Input[builtins.str] description: Description of the webhook.
        :param pulumi.Input[builtins.bool] enable_ssl_verification: Enable SSL verification when invoking the hook.
        :param pulumi.Input[builtins.bool] issues_events: Invoke the hook for issues events.
        :param pulumi.Input[builtins.bool] job_events: Invoke the hook for job events.
        :param pulumi.Input[builtins.bool] merge_requests_events: Invoke the hook for merge requests events.
        :param pulumi.Input[builtins.str] name: Name of the project webhook.
        :param pulumi.Input[builtins.bool] note_events: Invoke the hook for note events.
        :param pulumi.Input[builtins.bool] pipeline_events: Invoke the hook for pipeline events.
        :param pulumi.Input[builtins.bool] push_events: Invoke the hook for push events.
        :param pulumi.Input[builtins.str] push_events_branch_filter: Invoke the hook for push events on matching branches only.
        :param pulumi.Input[builtins.bool] releases_events: Invoke the hook for release events.
        :param pulumi.Input[builtins.bool] resource_access_token_events: Invoke the hook for project access token expiry events.
        :param pulumi.Input[builtins.bool] tag_push_events: Invoke the hook for tag push events.
        :param pulumi.Input[builtins.str] token: A token to present when invoking the hook. The token is not available for imported resources.
        :param pulumi.Input[builtins.bool] wiki_page_events: Invoke the hook for wiki page events.
        """
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "url", url)
        if confidential_issues_events is not None:
            pulumi.set(__self__, "confidential_issues_events", confidential_issues_events)
        if confidential_note_events is not None:
            pulumi.set(__self__, "confidential_note_events", confidential_note_events)
        if custom_headers is not None:
            pulumi.set(__self__, "custom_headers", custom_headers)
        if custom_webhook_template is not None:
            pulumi.set(__self__, "custom_webhook_template", custom_webhook_template)
        if deployment_events is not None:
            pulumi.set(__self__, "deployment_events", deployment_events)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_ssl_verification is not None:
            pulumi.set(__self__, "enable_ssl_verification", enable_ssl_verification)
        if issues_events is not None:
            pulumi.set(__self__, "issues_events", issues_events)
        if job_events is not None:
            pulumi.set(__self__, "job_events", job_events)
        if merge_requests_events is not None:
            pulumi.set(__self__, "merge_requests_events", merge_requests_events)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if note_events is not None:
            pulumi.set(__self__, "note_events", note_events)
        if pipeline_events is not None:
            pulumi.set(__self__, "pipeline_events", pipeline_events)
        if push_events is not None:
            pulumi.set(__self__, "push_events", push_events)
        if push_events_branch_filter is not None:
            pulumi.set(__self__, "push_events_branch_filter", push_events_branch_filter)
        if releases_events is not None:
            pulumi.set(__self__, "releases_events", releases_events)
        if resource_access_token_events is not None:
            pulumi.set(__self__, "resource_access_token_events", resource_access_token_events)
        if tag_push_events is not None:
            pulumi.set(__self__, "tag_push_events", tag_push_events)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if wiki_page_events is not None:
            pulumi.set(__self__, "wiki_page_events", wiki_page_events)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[builtins.str]:
        """
        The name or id of the project to add the hook to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def url(self) -> pulumi.Input[builtins.str]:
        """
        The url of the hook to invoke. Forces re-creation to preserve `token`.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter(name="confidentialIssuesEvents")
    def confidential_issues_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for confidential issues events.
        """
        return pulumi.get(self, "confidential_issues_events")

    @confidential_issues_events.setter
    def confidential_issues_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "confidential_issues_events", value)

    @property
    @pulumi.getter(name="confidentialNoteEvents")
    def confidential_note_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for confidential note events.
        """
        return pulumi.get(self, "confidential_note_events")

    @confidential_note_events.setter
    def confidential_note_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "confidential_note_events", value)

    @property
    @pulumi.getter(name="customHeaders")
    def custom_headers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectHookCustomHeaderArgs']]]]:
        """
        Custom headers for the project webhook.
        """
        return pulumi.get(self, "custom_headers")

    @custom_headers.setter
    def custom_headers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectHookCustomHeaderArgs']]]]):
        pulumi.set(self, "custom_headers", value)

    @property
    @pulumi.getter(name="customWebhookTemplate")
    def custom_webhook_template(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom webhook template.
        """
        return pulumi.get(self, "custom_webhook_template")

    @custom_webhook_template.setter
    def custom_webhook_template(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_webhook_template", value)

    @property
    @pulumi.getter(name="deploymentEvents")
    def deployment_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for deployment events.
        """
        return pulumi.get(self, "deployment_events")

    @deployment_events.setter
    def deployment_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "deployment_events", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the webhook.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableSslVerification")
    def enable_ssl_verification(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable SSL verification when invoking the hook.
        """
        return pulumi.get(self, "enable_ssl_verification")

    @enable_ssl_verification.setter
    def enable_ssl_verification(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_ssl_verification", value)

    @property
    @pulumi.getter(name="issuesEvents")
    def issues_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for issues events.
        """
        return pulumi.get(self, "issues_events")

    @issues_events.setter
    def issues_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "issues_events", value)

    @property
    @pulumi.getter(name="jobEvents")
    def job_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for job events.
        """
        return pulumi.get(self, "job_events")

    @job_events.setter
    def job_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "job_events", value)

    @property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for merge requests events.
        """
        return pulumi.get(self, "merge_requests_events")

    @merge_requests_events.setter
    def merge_requests_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "merge_requests_events", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the project webhook.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="noteEvents")
    def note_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for note events.
        """
        return pulumi.get(self, "note_events")

    @note_events.setter
    def note_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "note_events", value)

    @property
    @pulumi.getter(name="pipelineEvents")
    def pipeline_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for pipeline events.
        """
        return pulumi.get(self, "pipeline_events")

    @pipeline_events.setter
    def pipeline_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "pipeline_events", value)

    @property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for push events.
        """
        return pulumi.get(self, "push_events")

    @push_events.setter
    def push_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "push_events", value)

    @property
    @pulumi.getter(name="pushEventsBranchFilter")
    def push_events_branch_filter(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Invoke the hook for push events on matching branches only.
        """
        return pulumi.get(self, "push_events_branch_filter")

    @push_events_branch_filter.setter
    def push_events_branch_filter(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "push_events_branch_filter", value)

    @property
    @pulumi.getter(name="releasesEvents")
    def releases_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for release events.
        """
        return pulumi.get(self, "releases_events")

    @releases_events.setter
    def releases_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "releases_events", value)

    @property
    @pulumi.getter(name="resourceAccessTokenEvents")
    def resource_access_token_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for project access token expiry events.
        """
        return pulumi.get(self, "resource_access_token_events")

    @resource_access_token_events.setter
    def resource_access_token_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "resource_access_token_events", value)

    @property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @tag_push_events.setter
    def tag_push_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "tag_push_events", value)

    @property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A token to present when invoking the hook. The token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "token", value)

    @property
    @pulumi.getter(name="wikiPageEvents")
    def wiki_page_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for wiki page events.
        """
        return pulumi.get(self, "wiki_page_events")

    @wiki_page_events.setter
    def wiki_page_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "wiki_page_events", value)


@pulumi.input_type
class _ProjectHookState:
    def __init__(__self__, *,
                 confidential_issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 confidential_note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectHookCustomHeaderArgs']]]] = None,
                 custom_webhook_template: Optional[pulumi.Input[builtins.str]] = None,
                 deployment_events: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_ssl_verification: Optional[pulumi.Input[builtins.bool]] = None,
                 hook_id: Optional[pulumi.Input[builtins.int]] = None,
                 issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 job_events: Optional[pulumi.Input[builtins.bool]] = None,
                 merge_requests_events: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 pipeline_events: Optional[pulumi.Input[builtins.bool]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 project_id: Optional[pulumi.Input[builtins.int]] = None,
                 push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 push_events_branch_filter: Optional[pulumi.Input[builtins.str]] = None,
                 releases_events: Optional[pulumi.Input[builtins.bool]] = None,
                 resource_access_token_events: Optional[pulumi.Input[builtins.bool]] = None,
                 tag_push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 token: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 wiki_page_events: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering ProjectHook resources.
        :param pulumi.Input[builtins.bool] confidential_issues_events: Invoke the hook for confidential issues events.
        :param pulumi.Input[builtins.bool] confidential_note_events: Invoke the hook for confidential note events.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectHookCustomHeaderArgs']]] custom_headers: Custom headers for the project webhook.
        :param pulumi.Input[builtins.str] custom_webhook_template: Custom webhook template.
        :param pulumi.Input[builtins.bool] deployment_events: Invoke the hook for deployment events.
        :param pulumi.Input[builtins.str] description: Description of the webhook.
        :param pulumi.Input[builtins.bool] enable_ssl_verification: Enable SSL verification when invoking the hook.
        :param pulumi.Input[builtins.int] hook_id: The id of the project hook.
        :param pulumi.Input[builtins.bool] issues_events: Invoke the hook for issues events.
        :param pulumi.Input[builtins.bool] job_events: Invoke the hook for job events.
        :param pulumi.Input[builtins.bool] merge_requests_events: Invoke the hook for merge requests events.
        :param pulumi.Input[builtins.str] name: Name of the project webhook.
        :param pulumi.Input[builtins.bool] note_events: Invoke the hook for note events.
        :param pulumi.Input[builtins.bool] pipeline_events: Invoke the hook for pipeline events.
        :param pulumi.Input[builtins.str] project: The name or id of the project to add the hook to.
        :param pulumi.Input[builtins.int] project_id: The id of the project for the hook.
        :param pulumi.Input[builtins.bool] push_events: Invoke the hook for push events.
        :param pulumi.Input[builtins.str] push_events_branch_filter: Invoke the hook for push events on matching branches only.
        :param pulumi.Input[builtins.bool] releases_events: Invoke the hook for release events.
        :param pulumi.Input[builtins.bool] resource_access_token_events: Invoke the hook for project access token expiry events.
        :param pulumi.Input[builtins.bool] tag_push_events: Invoke the hook for tag push events.
        :param pulumi.Input[builtins.str] token: A token to present when invoking the hook. The token is not available for imported resources.
        :param pulumi.Input[builtins.str] url: The url of the hook to invoke. Forces re-creation to preserve `token`.
        :param pulumi.Input[builtins.bool] wiki_page_events: Invoke the hook for wiki page events.
        """
        if confidential_issues_events is not None:
            pulumi.set(__self__, "confidential_issues_events", confidential_issues_events)
        if confidential_note_events is not None:
            pulumi.set(__self__, "confidential_note_events", confidential_note_events)
        if custom_headers is not None:
            pulumi.set(__self__, "custom_headers", custom_headers)
        if custom_webhook_template is not None:
            pulumi.set(__self__, "custom_webhook_template", custom_webhook_template)
        if deployment_events is not None:
            pulumi.set(__self__, "deployment_events", deployment_events)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_ssl_verification is not None:
            pulumi.set(__self__, "enable_ssl_verification", enable_ssl_verification)
        if hook_id is not None:
            pulumi.set(__self__, "hook_id", hook_id)
        if issues_events is not None:
            pulumi.set(__self__, "issues_events", issues_events)
        if job_events is not None:
            pulumi.set(__self__, "job_events", job_events)
        if merge_requests_events is not None:
            pulumi.set(__self__, "merge_requests_events", merge_requests_events)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if note_events is not None:
            pulumi.set(__self__, "note_events", note_events)
        if pipeline_events is not None:
            pulumi.set(__self__, "pipeline_events", pipeline_events)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if push_events is not None:
            pulumi.set(__self__, "push_events", push_events)
        if push_events_branch_filter is not None:
            pulumi.set(__self__, "push_events_branch_filter", push_events_branch_filter)
        if releases_events is not None:
            pulumi.set(__self__, "releases_events", releases_events)
        if resource_access_token_events is not None:
            pulumi.set(__self__, "resource_access_token_events", resource_access_token_events)
        if tag_push_events is not None:
            pulumi.set(__self__, "tag_push_events", tag_push_events)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if wiki_page_events is not None:
            pulumi.set(__self__, "wiki_page_events", wiki_page_events)

    @property
    @pulumi.getter(name="confidentialIssuesEvents")
    def confidential_issues_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for confidential issues events.
        """
        return pulumi.get(self, "confidential_issues_events")

    @confidential_issues_events.setter
    def confidential_issues_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "confidential_issues_events", value)

    @property
    @pulumi.getter(name="confidentialNoteEvents")
    def confidential_note_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for confidential note events.
        """
        return pulumi.get(self, "confidential_note_events")

    @confidential_note_events.setter
    def confidential_note_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "confidential_note_events", value)

    @property
    @pulumi.getter(name="customHeaders")
    def custom_headers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectHookCustomHeaderArgs']]]]:
        """
        Custom headers for the project webhook.
        """
        return pulumi.get(self, "custom_headers")

    @custom_headers.setter
    def custom_headers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectHookCustomHeaderArgs']]]]):
        pulumi.set(self, "custom_headers", value)

    @property
    @pulumi.getter(name="customWebhookTemplate")
    def custom_webhook_template(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom webhook template.
        """
        return pulumi.get(self, "custom_webhook_template")

    @custom_webhook_template.setter
    def custom_webhook_template(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_webhook_template", value)

    @property
    @pulumi.getter(name="deploymentEvents")
    def deployment_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for deployment events.
        """
        return pulumi.get(self, "deployment_events")

    @deployment_events.setter
    def deployment_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "deployment_events", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the webhook.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableSslVerification")
    def enable_ssl_verification(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable SSL verification when invoking the hook.
        """
        return pulumi.get(self, "enable_ssl_verification")

    @enable_ssl_verification.setter
    def enable_ssl_verification(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_ssl_verification", value)

    @property
    @pulumi.getter(name="hookId")
    def hook_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The id of the project hook.
        """
        return pulumi.get(self, "hook_id")

    @hook_id.setter
    def hook_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "hook_id", value)

    @property
    @pulumi.getter(name="issuesEvents")
    def issues_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for issues events.
        """
        return pulumi.get(self, "issues_events")

    @issues_events.setter
    def issues_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "issues_events", value)

    @property
    @pulumi.getter(name="jobEvents")
    def job_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for job events.
        """
        return pulumi.get(self, "job_events")

    @job_events.setter
    def job_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "job_events", value)

    @property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for merge requests events.
        """
        return pulumi.get(self, "merge_requests_events")

    @merge_requests_events.setter
    def merge_requests_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "merge_requests_events", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the project webhook.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="noteEvents")
    def note_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for note events.
        """
        return pulumi.get(self, "note_events")

    @note_events.setter
    def note_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "note_events", value)

    @property
    @pulumi.getter(name="pipelineEvents")
    def pipeline_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for pipeline events.
        """
        return pulumi.get(self, "pipeline_events")

    @pipeline_events.setter
    def pipeline_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "pipeline_events", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name or id of the project to add the hook to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The id of the project for the hook.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for push events.
        """
        return pulumi.get(self, "push_events")

    @push_events.setter
    def push_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "push_events", value)

    @property
    @pulumi.getter(name="pushEventsBranchFilter")
    def push_events_branch_filter(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Invoke the hook for push events on matching branches only.
        """
        return pulumi.get(self, "push_events_branch_filter")

    @push_events_branch_filter.setter
    def push_events_branch_filter(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "push_events_branch_filter", value)

    @property
    @pulumi.getter(name="releasesEvents")
    def releases_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for release events.
        """
        return pulumi.get(self, "releases_events")

    @releases_events.setter
    def releases_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "releases_events", value)

    @property
    @pulumi.getter(name="resourceAccessTokenEvents")
    def resource_access_token_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for project access token expiry events.
        """
        return pulumi.get(self, "resource_access_token_events")

    @resource_access_token_events.setter
    def resource_access_token_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "resource_access_token_events", value)

    @property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @tag_push_events.setter
    def tag_push_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "tag_push_events", value)

    @property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A token to present when invoking the hook. The token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "token", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The url of the hook to invoke. Forces re-creation to preserve `token`.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter(name="wikiPageEvents")
    def wiki_page_events(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Invoke the hook for wiki page events.
        """
        return pulumi.get(self, "wiki_page_events")

    @wiki_page_events.setter
    def wiki_page_events(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "wiki_page_events", value)


class ProjectHook(pulumi.CustomResource):

    pulumi_type = "gitlab:index/projectHook:ProjectHook"

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 confidential_issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 confidential_note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectHookCustomHeaderArgs', 'ProjectHookCustomHeaderArgsDict']]]]] = None,
                 custom_webhook_template: Optional[pulumi.Input[builtins.str]] = None,
                 deployment_events: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_ssl_verification: Optional[pulumi.Input[builtins.bool]] = None,
                 issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 job_events: Optional[pulumi.Input[builtins.bool]] = None,
                 merge_requests_events: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 pipeline_events: Optional[pulumi.Input[builtins.bool]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 push_events_branch_filter: Optional[pulumi.Input[builtins.str]] = None,
                 releases_events: Optional[pulumi.Input[builtins.bool]] = None,
                 resource_access_token_events: Optional[pulumi.Input[builtins.bool]] = None,
                 tag_push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 token: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 wiki_page_events: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        The `ProjectHook` resource allows to manage the lifecycle of a project hook.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/projects/#hooks)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.ProjectHook("example",
            project="example/hooked",
            url="https://example.com/hook/example",
            name="example",
            description="Example hook",
            merge_requests_events=True)
        # Using Custom Headers
        # Values of headers can't be imported
        custom_headers = gitlab.ProjectHook("custom_headers",
            project="example/hooked",
            url="https://example.com/hook/example",
            merge_requests_events=True,
            custom_headers=[
                {
                    "key": "X-Custom-Header",
                    "value": "example",
                },
                {
                    "key": "X-Custom-Header-Second",
                    "value": "example-second",
                },
            ])
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_hook`. For example:

        terraform

        import {

          to = gitlab_project_hook.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        A GitLab Project Hook can be imported using a key composed of `<project-id>:<hook-id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectHook:ProjectHook example "12345:1"
        ```

        NOTE: the `token` resource attribute is not available for imported resources as this information cannot be read from the GitLab API.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] confidential_issues_events: Invoke the hook for confidential issues events.
        :param pulumi.Input[builtins.bool] confidential_note_events: Invoke the hook for confidential note events.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProjectHookCustomHeaderArgs', 'ProjectHookCustomHeaderArgsDict']]]] custom_headers: Custom headers for the project webhook.
        :param pulumi.Input[builtins.str] custom_webhook_template: Custom webhook template.
        :param pulumi.Input[builtins.bool] deployment_events: Invoke the hook for deployment events.
        :param pulumi.Input[builtins.str] description: Description of the webhook.
        :param pulumi.Input[builtins.bool] enable_ssl_verification: Enable SSL verification when invoking the hook.
        :param pulumi.Input[builtins.bool] issues_events: Invoke the hook for issues events.
        :param pulumi.Input[builtins.bool] job_events: Invoke the hook for job events.
        :param pulumi.Input[builtins.bool] merge_requests_events: Invoke the hook for merge requests events.
        :param pulumi.Input[builtins.str] name: Name of the project webhook.
        :param pulumi.Input[builtins.bool] note_events: Invoke the hook for note events.
        :param pulumi.Input[builtins.bool] pipeline_events: Invoke the hook for pipeline events.
        :param pulumi.Input[builtins.str] project: The name or id of the project to add the hook to.
        :param pulumi.Input[builtins.bool] push_events: Invoke the hook for push events.
        :param pulumi.Input[builtins.str] push_events_branch_filter: Invoke the hook for push events on matching branches only.
        :param pulumi.Input[builtins.bool] releases_events: Invoke the hook for release events.
        :param pulumi.Input[builtins.bool] resource_access_token_events: Invoke the hook for project access token expiry events.
        :param pulumi.Input[builtins.bool] tag_push_events: Invoke the hook for tag push events.
        :param pulumi.Input[builtins.str] token: A token to present when invoking the hook. The token is not available for imported resources.
        :param pulumi.Input[builtins.str] url: The url of the hook to invoke. Forces re-creation to preserve `token`.
        :param pulumi.Input[builtins.bool] wiki_page_events: Invoke the hook for wiki page events.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectHookArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectHook` resource allows to manage the lifecycle of a project hook.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/projects/#hooks)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.ProjectHook("example",
            project="example/hooked",
            url="https://example.com/hook/example",
            name="example",
            description="Example hook",
            merge_requests_events=True)
        # Using Custom Headers
        # Values of headers can't be imported
        custom_headers = gitlab.ProjectHook("custom_headers",
            project="example/hooked",
            url="https://example.com/hook/example",
            merge_requests_events=True,
            custom_headers=[
                {
                    "key": "X-Custom-Header",
                    "value": "example",
                },
                {
                    "key": "X-Custom-Header-Second",
                    "value": "example-second",
                },
            ])
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_hook`. For example:

        terraform

        import {

          to = gitlab_project_hook.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        A GitLab Project Hook can be imported using a key composed of `<project-id>:<hook-id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectHook:ProjectHook example "12345:1"
        ```

        NOTE: the `token` resource attribute is not available for imported resources as this information cannot be read from the GitLab API.

        :param str resource_name: The name of the resource.
        :param ProjectHookArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectHookArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 confidential_issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 confidential_note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectHookCustomHeaderArgs', 'ProjectHookCustomHeaderArgsDict']]]]] = None,
                 custom_webhook_template: Optional[pulumi.Input[builtins.str]] = None,
                 deployment_events: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_ssl_verification: Optional[pulumi.Input[builtins.bool]] = None,
                 issues_events: Optional[pulumi.Input[builtins.bool]] = None,
                 job_events: Optional[pulumi.Input[builtins.bool]] = None,
                 merge_requests_events: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 note_events: Optional[pulumi.Input[builtins.bool]] = None,
                 pipeline_events: Optional[pulumi.Input[builtins.bool]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 push_events_branch_filter: Optional[pulumi.Input[builtins.str]] = None,
                 releases_events: Optional[pulumi.Input[builtins.bool]] = None,
                 resource_access_token_events: Optional[pulumi.Input[builtins.bool]] = None,
                 tag_push_events: Optional[pulumi.Input[builtins.bool]] = None,
                 token: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 wiki_page_events: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectHookArgs.__new__(ProjectHookArgs)

            __props__.__dict__["confidential_issues_events"] = confidential_issues_events
            __props__.__dict__["confidential_note_events"] = confidential_note_events
            __props__.__dict__["custom_headers"] = custom_headers
            __props__.__dict__["custom_webhook_template"] = custom_webhook_template
            __props__.__dict__["deployment_events"] = deployment_events
            __props__.__dict__["description"] = description
            __props__.__dict__["enable_ssl_verification"] = enable_ssl_verification
            __props__.__dict__["issues_events"] = issues_events
            __props__.__dict__["job_events"] = job_events
            __props__.__dict__["merge_requests_events"] = merge_requests_events
            __props__.__dict__["name"] = name
            __props__.__dict__["note_events"] = note_events
            __props__.__dict__["pipeline_events"] = pipeline_events
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["push_events"] = push_events
            __props__.__dict__["push_events_branch_filter"] = push_events_branch_filter
            __props__.__dict__["releases_events"] = releases_events
            __props__.__dict__["resource_access_token_events"] = resource_access_token_events
            __props__.__dict__["tag_push_events"] = tag_push_events
            __props__.__dict__["token"] = None if token is None else pulumi.Output.secret(token)
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
            __props__.__dict__["wiki_page_events"] = wiki_page_events
            __props__.__dict__["hook_id"] = None
            __props__.__dict__["project_id"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ProjectHook, __self__).__init__(
            'gitlab:index/projectHook:ProjectHook',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            confidential_issues_events: Optional[pulumi.Input[builtins.bool]] = None,
            confidential_note_events: Optional[pulumi.Input[builtins.bool]] = None,
            custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectHookCustomHeaderArgs', 'ProjectHookCustomHeaderArgsDict']]]]] = None,
            custom_webhook_template: Optional[pulumi.Input[builtins.str]] = None,
            deployment_events: Optional[pulumi.Input[builtins.bool]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            enable_ssl_verification: Optional[pulumi.Input[builtins.bool]] = None,
            hook_id: Optional[pulumi.Input[builtins.int]] = None,
            issues_events: Optional[pulumi.Input[builtins.bool]] = None,
            job_events: Optional[pulumi.Input[builtins.bool]] = None,
            merge_requests_events: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            note_events: Optional[pulumi.Input[builtins.bool]] = None,
            pipeline_events: Optional[pulumi.Input[builtins.bool]] = None,
            project: Optional[pulumi.Input[builtins.str]] = None,
            project_id: Optional[pulumi.Input[builtins.int]] = None,
            push_events: Optional[pulumi.Input[builtins.bool]] = None,
            push_events_branch_filter: Optional[pulumi.Input[builtins.str]] = None,
            releases_events: Optional[pulumi.Input[builtins.bool]] = None,
            resource_access_token_events: Optional[pulumi.Input[builtins.bool]] = None,
            tag_push_events: Optional[pulumi.Input[builtins.bool]] = None,
            token: Optional[pulumi.Input[builtins.str]] = None,
            url: Optional[pulumi.Input[builtins.str]] = None,
            wiki_page_events: Optional[pulumi.Input[builtins.bool]] = None) -> 'ProjectHook':
        """
        Get an existing ProjectHook resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] confidential_issues_events: Invoke the hook for confidential issues events.
        :param pulumi.Input[builtins.bool] confidential_note_events: Invoke the hook for confidential note events.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProjectHookCustomHeaderArgs', 'ProjectHookCustomHeaderArgsDict']]]] custom_headers: Custom headers for the project webhook.
        :param pulumi.Input[builtins.str] custom_webhook_template: Custom webhook template.
        :param pulumi.Input[builtins.bool] deployment_events: Invoke the hook for deployment events.
        :param pulumi.Input[builtins.str] description: Description of the webhook.
        :param pulumi.Input[builtins.bool] enable_ssl_verification: Enable SSL verification when invoking the hook.
        :param pulumi.Input[builtins.int] hook_id: The id of the project hook.
        :param pulumi.Input[builtins.bool] issues_events: Invoke the hook for issues events.
        :param pulumi.Input[builtins.bool] job_events: Invoke the hook for job events.
        :param pulumi.Input[builtins.bool] merge_requests_events: Invoke the hook for merge requests events.
        :param pulumi.Input[builtins.str] name: Name of the project webhook.
        :param pulumi.Input[builtins.bool] note_events: Invoke the hook for note events.
        :param pulumi.Input[builtins.bool] pipeline_events: Invoke the hook for pipeline events.
        :param pulumi.Input[builtins.str] project: The name or id of the project to add the hook to.
        :param pulumi.Input[builtins.int] project_id: The id of the project for the hook.
        :param pulumi.Input[builtins.bool] push_events: Invoke the hook for push events.
        :param pulumi.Input[builtins.str] push_events_branch_filter: Invoke the hook for push events on matching branches only.
        :param pulumi.Input[builtins.bool] releases_events: Invoke the hook for release events.
        :param pulumi.Input[builtins.bool] resource_access_token_events: Invoke the hook for project access token expiry events.
        :param pulumi.Input[builtins.bool] tag_push_events: Invoke the hook for tag push events.
        :param pulumi.Input[builtins.str] token: A token to present when invoking the hook. The token is not available for imported resources.
        :param pulumi.Input[builtins.str] url: The url of the hook to invoke. Forces re-creation to preserve `token`.
        :param pulumi.Input[builtins.bool] wiki_page_events: Invoke the hook for wiki page events.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectHookState.__new__(_ProjectHookState)

        __props__.__dict__["confidential_issues_events"] = confidential_issues_events
        __props__.__dict__["confidential_note_events"] = confidential_note_events
        __props__.__dict__["custom_headers"] = custom_headers
        __props__.__dict__["custom_webhook_template"] = custom_webhook_template
        __props__.__dict__["deployment_events"] = deployment_events
        __props__.__dict__["description"] = description
        __props__.__dict__["enable_ssl_verification"] = enable_ssl_verification
        __props__.__dict__["hook_id"] = hook_id
        __props__.__dict__["issues_events"] = issues_events
        __props__.__dict__["job_events"] = job_events
        __props__.__dict__["merge_requests_events"] = merge_requests_events
        __props__.__dict__["name"] = name
        __props__.__dict__["note_events"] = note_events
        __props__.__dict__["pipeline_events"] = pipeline_events
        __props__.__dict__["project"] = project
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["push_events"] = push_events
        __props__.__dict__["push_events_branch_filter"] = push_events_branch_filter
        __props__.__dict__["releases_events"] = releases_events
        __props__.__dict__["resource_access_token_events"] = resource_access_token_events
        __props__.__dict__["tag_push_events"] = tag_push_events
        __props__.__dict__["token"] = token
        __props__.__dict__["url"] = url
        __props__.__dict__["wiki_page_events"] = wiki_page_events
        return ProjectHook(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="confidentialIssuesEvents")
    def confidential_issues_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for confidential issues events.
        """
        return pulumi.get(self, "confidential_issues_events")

    @property
    @pulumi.getter(name="confidentialNoteEvents")
    def confidential_note_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for confidential note events.
        """
        return pulumi.get(self, "confidential_note_events")

    @property
    @pulumi.getter(name="customHeaders")
    def custom_headers(self) -> pulumi.Output[Optional[Sequence['outputs.ProjectHookCustomHeader']]]:
        """
        Custom headers for the project webhook.
        """
        return pulumi.get(self, "custom_headers")

    @property
    @pulumi.getter(name="customWebhookTemplate")
    def custom_webhook_template(self) -> pulumi.Output[builtins.str]:
        """
        Custom webhook template.
        """
        return pulumi.get(self, "custom_webhook_template")

    @property
    @pulumi.getter(name="deploymentEvents")
    def deployment_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for deployment events.
        """
        return pulumi.get(self, "deployment_events")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Description of the webhook.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableSslVerification")
    def enable_ssl_verification(self) -> pulumi.Output[builtins.bool]:
        """
        Enable SSL verification when invoking the hook.
        """
        return pulumi.get(self, "enable_ssl_verification")

    @property
    @pulumi.getter(name="hookId")
    def hook_id(self) -> pulumi.Output[builtins.int]:
        """
        The id of the project hook.
        """
        return pulumi.get(self, "hook_id")

    @property
    @pulumi.getter(name="issuesEvents")
    def issues_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for issues events.
        """
        return pulumi.get(self, "issues_events")

    @property
    @pulumi.getter(name="jobEvents")
    def job_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for job events.
        """
        return pulumi.get(self, "job_events")

    @property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for merge requests events.
        """
        return pulumi.get(self, "merge_requests_events")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Name of the project webhook.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="noteEvents")
    def note_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for note events.
        """
        return pulumi.get(self, "note_events")

    @property
    @pulumi.getter(name="pipelineEvents")
    def pipeline_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for pipeline events.
        """
        return pulumi.get(self, "pipeline_events")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[builtins.str]:
        """
        The name or id of the project to add the hook to.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[builtins.int]:
        """
        The id of the project for the hook.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for push events.
        """
        return pulumi.get(self, "push_events")

    @property
    @pulumi.getter(name="pushEventsBranchFilter")
    def push_events_branch_filter(self) -> pulumi.Output[builtins.str]:
        """
        Invoke the hook for push events on matching branches only.
        """
        return pulumi.get(self, "push_events_branch_filter")

    @property
    @pulumi.getter(name="releasesEvents")
    def releases_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for release events.
        """
        return pulumi.get(self, "releases_events")

    @property
    @pulumi.getter(name="resourceAccessTokenEvents")
    def resource_access_token_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for project access token expiry events.
        """
        return pulumi.get(self, "resource_access_token_events")

    @property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @property
    @pulumi.getter
    def token(self) -> pulumi.Output[builtins.str]:
        """
        A token to present when invoking the hook. The token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[builtins.str]:
        """
        The url of the hook to invoke. Forces re-creation to preserve `token`.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter(name="wikiPageEvents")
    def wiki_page_events(self) -> pulumi.Output[builtins.bool]:
        """
        Invoke the hook for wiki page events.
        """
        return pulumi.get(self, "wiki_page_events")

